@@ -1,16 +1,12 @@
 from ormar.relations.alias_manager import AliasManager
 from ormar.relations.relation import Relation, RelationType
 from ormar.relations.relation_manager import RelationsManager
-from ormar.relations.utils import (
-    get_relations_sides_and_names,
-    register_missing_relation,
-)
+from ormar.relations.utils import get_relations_sides_and_names
 
 __all__ = [
     "AliasManager",
     "Relation",
     "RelationsManager",
     "RelationType",
-    "register_missing_relation",
     "get_relations_sides_and_names",
 ]
